RevocationListInfos

Struct RevocationListInfos 

pub struct RevocationListInfos { /* private fields */ }
Represents collection of revocation list infos which can be sent in license challenge.

Implementations

Source

impl RevocationListInfos

pub fn initial() -> Self

Returns an initial revocation list infos (if no other are available).

pub fn iter(&self) -> impl Iterator<Item = &RevocationListInfo>

Returns an iterator to revocation list infos.

pub fn from_revocation_lists(rev_lists: &RevocationLists) -> Self

Creates revocation list infos from revocation lists.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Constructs new RevocationListInfos by deserializing bytes in PRL format.

pub fn from_prl(path: impl AsRef<Path>) -> Result<Self, Error>

Constructs new RevocationListInfos by deserializing bytes from prl file.

pub fn write_to_file(&self, path: impl AsRef<Path>) -> Result<(), Error>

Writes infos to the prl file.

pub fn update(&mut self, other: &Self) -> bool

Updates current revocation lists with the new ones specified in other argument.

Returns true if at least one of the items has been updated.